pub struct TableConfig {
pub name: String,
pub xml_path: String,
pub levels: Vec<String>,
pub fields: Vec<FieldConfig>,
}Expand description
Configuration for an XML table to be parsed into an Arrow record batch.
This struct defines how an XML structure should be interpreted as a table, including the path to the table elements, the element representing a row, and the configuration of the fields (columns) within the table.
Fields
name: StringThe name of the table.
xml_path: StringThe XML path to the table elements. For example /data/dataset/table.
levels: Vec<String>The levels of nesting for this table. This is used to create the indices for nested tables.
For example if the xml_path is /data/dataset/table/item/properties the levels should
be ["table", "properties"].
fields: Vec<FieldConfig>A vector of FieldConfig structs, each defining a field (column) in the table.
Implementations